//----------------------------------------------------------------------
//
//  Copyright(c) 2001, Richard Nies
//
//  Permission granted to use this code without restriction as
//  long as this copyright notice appears in all source files.
//
//  Class:        CorbaExcep
//
//  File:         CorbaExcep.h
//
//  Description:  Defines a Corba Exception.  The subID should 
//                indicate the particular Corba exception type.
//               
//----------------------------------------------------------------------
#ifndef _CORBAEXCEP_H
#define _CORBAEXCEP_H

// System Includes

// Local Includes

#include "../Common/CommonExcep.h"

// Macros

//----------------------------------------------------------------------
// Class: Common Exception (CorbaExcep)
//----------------------------------------------------------------------
class CorbaExcep : public CommonExcep
{
public:

   //---
   // Constructors/Destructors
   //---

   CorbaExcep
      (const char* file,
       const char* method,
       const int   line,
       const char* errMsg  = "",
       const int   errCode = 0,
       const char* subID   = "");

   virtual ~CorbaExcep() {}

   //---
   // Information methods.
   //---
     
   virtual const char* id() const;
   // Returns the unique text id to identify this exception.

protected:

   //---
   // Constructors/Destructors
   //---

   CorbaExcep
      (const char* id,
       const char* file,
       const char* method,
       const int   line,
       const char* errMsg,
       const int   errCode,
       const char* subID);
   // Used by derived exception classes.

private:

};  

//----------------------------------------------------------------------
// Inline Method: Constructor
//----------------------------------------------------------------------
inline
CorbaExcep::CorbaExcep
                  (const char* id,
                   const char* file,
                   const char* method,
                   const int   line,
                   const char* errMsg,
                   const int   errCode,
                   const char* subID)     
  :
      CommonExcep
         (id, file, method, line, errMsg, errCode, subID)
{}

#endif



