//----------------------------------------------------------------------
//
//  Copyright(c) 2001, Richard Nies
//
//  Permission granted to use this code without restriction as
//  long as this copyright notice appears in all source files.
//
//  Class:        CorbaSystemExcep
//
//  File:         CorbaSystemExcep.h
//
//  Description:  Defines a Corba System Exception.  
//               
//----------------------------------------------------------------------
#ifndef _CORBASYSTEMEXCEP_H
#define _CORBASYSTEMEXCEP_H

// System Includes

#include <CORBA.h>

// Local Includes

#include "../Common/CorbaExcep.h"

// Macros

//----------------------------------------------------------------------
// Class: Common Exception (CorbaSystemExcep)
//----------------------------------------------------------------------
class CorbaSystemExcep : public CorbaExcep
{
public:

   //---
   // Constructors/Destructors
   //---

   CorbaSystemExcep
      (const char*                   file,
       const char*                   method,
       const int                     line,
       const CORBA::ULong            minorCode,
       const CORBA::CompletionStatus status,
       const char*                   errMsg  = "",
       const int                     errCode = 0,
       const char*                   subID   = "");

   virtual ~CorbaSystemExcep() {}

   //---
   // Directive methods.
   //---
   
   void                throwCorba() const;
   // This method causes this class to throw the original
   // CORBA system exception that it represents.

   //---
   // Information methods.
   //---
     
   virtual const char* id() const;
   // Returns the unique text id to identify this exception.

protected:

   //---
   // Constructors/Destructors
   //---

   CorbaSystemExcep
      (const char*                   id,
       const char*                   file,
       const char*                   method,
       const int                     line,
       const CORBA::ULong            minorCode,
       const CORBA::CompletionStatus status,
       const char*                   errMsg,
       const int                     errCode,
       const char*                   subID);
   // Used by derived exception classes.

   //---
   // Data members
   //---

   CORBA::ULong              m_minorCode;
   // The minor code identifying the system excep.

   CORBA::CompletionStatus   m_completionStatus;
   // The completion status of the system excep.

private:

};  

//----------------------------------------------------------------------
// Inline Method: Constructor
//----------------------------------------------------------------------
inline
CorbaSystemExcep::CorbaSystemExcep
                  (const char*                   id,
                   const char*                   file,
                   const char*                   method,
                   const int                     line,
                   const CORBA::ULong            minorCode,
                   const CORBA::CompletionStatus status,
                   const char*                   errMsg,
                   const int                     errCode,
                   const char*                   subID)     
  :
     CorbaExcep         (id, file, method, line, errMsg, errCode, subID),
     m_minorCode        (minorCode),
     m_completionStatus (status)
{}

//----------------------------------------------------------------------
// Inline Method: throwCorba
//----------------------------------------------------------------------
inline
void CorbaSystemExcep::throwCorba() const
{
   throw CORBA::SystemException(m_minorCode, m_completionStatus);
}
#endif



