//----------------------------------------------------------------------
//
//  Copyright(c) 2001, Richard Nies
//
//  Permission granted to use this code without restriction as
//  long as this copyright notice appears in all source files.
//
//  Class:        CorbaUserExcep
//
//  File:         CorbaUserExcep.h
//
//  Description:  Defines a Corba Exception.  The subID should 
//                indicate the particular Corba exception type.
//               
//----------------------------------------------------------------------
#ifndef _CORBAUSEREXCEP_H
#define _CORBAUSEREXCEP_H

// System Includes

// Local Includes

#include "../Common/CorbaExcep.h"

// Macros

//----------------------------------------------------------------------
// Class: Corba User Exception (CorbaUserExcep)
//----------------------------------------------------------------------
class CorbaUserExcep : public CorbaExcep
{
public:

   //---
   // Constructors/Destructors
   //---

   CorbaUserExcep
      (const char* file,
       const char* method,
       const int   line,
       const char* errMsg  = "",
       const int   errCode = 0,
       const char* subID   = "");

   virtual ~CorbaUserExcep() {}

   //---
   // Information methods.
   //---
     
   virtual const char* id() const;
   // Returns the unique text id to identify this exception.

protected:

   //---
   // Constructors/Destructors
   //---

   CorbaUserExcep
      (const char* id,
       const char* file,
       const char* method,
       const int   line,
       const char* errMsg,
       const int   errCode,
       const char* subID);
   // Used by derived exception classes.

private:

};  

//----------------------------------------------------------------------
// Inline Method: Constructor
//----------------------------------------------------------------------
inline
CorbaUserExcep::CorbaUserExcep
                  (const char* id,
                   const char* file,
                   const char* method,
                   const int   line,
                   const char* errMsg,
                   const int   errCode,
                   const char* subID)     
  :
      CorbaExcep
         (id, file, method, line, errMsg, errCode, subID)
{}

#endif



