//----------------------------------------------------------------------
//
//  Class:        ExcepInfo
//
//  File:         ExcepInfo.h
//
//  Description:  Defines the information stored for a single exception. 
//               
//----------------------------------------------------------------------
#ifndef _EXCEPINFO_H
#define _EXCEPINFO_H

// System Includes

#include <string>

// Local Includes

// Forward declarations;

//----------------------------------------------------------------------
// Class: ExcepInfo
//----------------------------------------------------------------------
class ExcepInfo
{
public:

   //---
   // Constructors/Destructors
   //---

   ExcepInfo(const char* id,
             const char* file,
             const char* method,
             const int   line,
             const char* errMsg,
             const int   errCode,
             const char* subID);

   //---
   // Accessor methods.
   //---
     
   const std::string& id()       const;
   // Returns the id of the exception (usually the name).

   const std::string& file()     const;
   // Returns the file in which the exception was thrown.

   const std::string& method()   const;
   // Returns the method in which the exception was thrown.

   const int          line()     const;
   // Returns the line at which the exception was thrown.

   const std::string& errMsg()   const;
   // Returns the errMsg  (if relevant) related to the exception.

   const int          errCode()  const;
   // Returns the errCode (if relevant) related to the exception.

   const std::string& subID()    const;
   // Returns the subID   (if relevant) related to the exception.
   // The subID can be used to identify the more specific nature of  
   // an exception that is being covered by a more general exception.
   // For example: a particular 3 party exception that is caught may
   // be raised as a more generic "Database Exception" and the
   // subID can track the more particular root cause.  

protected:

   //---
   // Data Members.
   //---

   std::string     m_id;
   std::string     m_file;
   std::string     m_method;
   int             m_line;
   std::string     m_errMsg;
   int             m_errCode;
   std::string     m_subID;

private:
         
   ExcepInfo();
   // No default constructor allowed.
};  

//----------------------------------------------------------------------
// Inline Method: id
//----------------------------------------------------------------------
inline
const std::string& ExcepInfo::id()  const
{
   return m_id;
}

//----------------------------------------------------------------------
// Inline Method: file
//----------------------------------------------------------------------
inline
const std::string& ExcepInfo::file()  const
{
   return m_file;
}

//----------------------------------------------------------------------
// Inline Method: method
//----------------------------------------------------------------------
inline
const std::string& ExcepInfo::method()  const
{
   return m_method;
}

//----------------------------------------------------------------------
// Inline Method: line
//----------------------------------------------------------------------
inline
const int ExcepInfo::line()  const
{
   return m_line;
}

//----------------------------------------------------------------------
// Inline Method: errMsg
//----------------------------------------------------------------------
inline
const std::string& ExcepInfo::errMsg()  const
{
   return m_errMsg;
}

//----------------------------------------------------------------------
// Inline Method: errCode
//----------------------------------------------------------------------
inline
const int ExcepInfo::errCode()  const
{
   return m_errCode;
}

//----------------------------------------------------------------------
// Inline Method: subID
//----------------------------------------------------------------------
inline
const std::string& ExcepInfo::subID()  const
{
   return m_subID;
}

#endif



