/**************************************************************
Module : TrcView.cpp      - trace buffer viewer
             Written 2000 by Dmitri Leman
Purpose: Tracer framework.
**************************************************************/
#include <windows.h>
#include "HTrace.h"
#include <winioctl.h>
#include "InstDrv.h"

static const char s_szDriverName[] = "HTrcDrv.sys";
static const char s_szDriverPath[] = "HTrcDrv.sys";
static const char s_szDeviceName[] = TRACER_WIN32_FILE_NAME_A;
static const char s_szProgramCaption[] = "StartDrv";

/*------------------------------------------------------------

   FUNCTION: bProgramBody

   PURPOSE: Called from WinMain.
      
   PARAMETERS:                   .
                                  
   HINSTANCE p_hInstance        handle to current instance
   HINSTANCE p_hPrevInstance    not used
   LPSTR  p_lpszCmdLine         pointer to command line
   int    p_nCmdShow            show state of window

   RETURN VALUE:
      BOOL  TRUE on success, FALSE on failure
-------------------------------------------------------------*/
BOOL bProgramBody
( 
    HINSTANCE p_hInstance, 
    HINSTANCE p_hPrevInstance,
    LPSTR  p_lpszCmdLine, 
    int    p_nCmdShow 
)
{
    char l_szDriverPath[_MAX_PATH];
    GetFullPathName(s_szDriverPath, 
        sizeof(l_szDriverPath), l_szDriverPath, NULL);

    if(!InstallDriver::bRegisterDriver(
        s_szDriverName, l_szDriverPath))
    {
        HTRACE(TG_MessageBox,
            "RegisterDriver(%s,%s) failed",
            s_szDriverName, s_szDriverPath);
        return FALSE;
    }

    HANDLE l_hDevice = NULL;
    if(!InstallDriver::bStartDriverAndOpenDevice(
        s_szDriverName, s_szDeviceName, &l_hDevice))
    {
        HTRACE(TG_MessageBox, "ERROR : StartDriver failed");
        return FALSE;
    }

    MessageBox(0,"The driver is running.Click OK to unload it",
        "StartDrv", MB_OK);

    CloseHandle(l_hDevice);

    bool l_bUnregister = false;
    if(IDYES == MessageBox(0,
        "Do you want to unregister the driver?",
        s_szProgramCaption, MB_YESNO))
    {
        l_bUnregister = true;
    }

    InstallDriver::bUnloadDriver(s_szDriverName,l_bUnregister);

    return TRUE;
}//BOOL bProgramBody

/*------------------------------------------------------------

   FUNCTION: WinMain

   PURPOSE: Initial entry point for the application.
      
   PARAMETERS:                   .
                                  
   HINSTANCE p_hInstance         handle to current instance
   HINSTANCE p_hPrevInstance     not used
   LPSTR  p_lpszCmdLine          pointer to command line
   int    p_nCmdShow             show state of window

   RETURN VALUE:
      int                        Exit value
-------------------------------------------------------------*/
int APIENTRY WinMain
( 
    HINSTANCE p_hInstance, 
    HINSTANCE p_hPrevInstance,
    LPSTR     p_lpszCmdLine, 
    int       p_nCmdShow 
)
{
    TraceInitialize();
    //For this simple application show errors and warnings on 
    //the debugger's log window and in message boxes
    TraceAssignGroupsToStream(TO_DebugMonitor | TO_MessageBox,
        TG_MessageBox | TG_Error, (DWORD)-1);

    BOOL l_bResult = bProgramBody(
        p_hInstance,p_hPrevInstance,p_lpszCmdLine,p_nCmdShow);
    TraceUnInitialize();
    return l_bResult? 0 : 1;
}//int APIENTRY WinMain

